@@ -3,7 +3,7 @@
 export CFLAGS="$CFLAGS -I$PREFIX/include -L$PREFIX/lib"
 export CPPFLAGS="$CPPFLAGS -I$PREFIX/include"
 
-./configure --prefix=$PREFIX --enable-expat_1_1
+./configure --prefix=$PREFIX --enable-expat_1_1 --disable-dependency-tracking
 
 make -j${CPU_COUNT} ${VERBOSE_AT}
 make check
